@@ -31,13 +31,13 @@ c     *GMOLD,GMNEW,SIGSQ,OLDB
 C*****series.txt
       CHARACTER*40 NAME
       INTEGER LEN
-      DOUBLE PRECISION TIM(500),SER(500),TDIF(500)
+      DOUBLE PRECISION TIM(5000),SER(5000),TDIF(5000)
 c      COMMON/SERIES/NAME,LEN,TIM,SER,TDIF
       COMMON/SERIES/TIM,SER,TDIF,NAME,LEN
 
 C*****veccom.txt
       DOUBLE PRECISION B(22),NEWB(22),PERB(22),DELB(22),
-     * ERR(500),RES(500),PRES(22,500),sres(500)
+     * ERR(5000),RES(5000),PRES(22,5000),sres(5000)
       COMMON/VECCOM/B,NEWB,PERB,DELB,ERR,RES,PRES,sres
 
 C*****redcom.txt
@@ -55,9 +55,10 @@ C*****repar3.txt
       COMMON/REPAR3/ALPHA,ROOTR,ROOTI,XVECR,XVECI
 
 C*****kfasav.txt
-      REAL PRE(500),PRV(500),FSER(500),FVAR(500),SSER(500),SVAR(500)
-      DOUBLE PRECISION FSES(500,20),FSCV(500,20,20),SSES(500,20)
-     1,SSCV(500,20,20),PSES(500,20),PSCV(500,20,20),TRAN(500,20,20)
+      REAL PRE(5000),PRV(5000),FSER(5000),FVAR(5000),SSER(5000)
+     1,SVAR(5000)
+      DOUBLE PRECISION FSES(5000,20),FSCV(5000,20,20),SSES(5000,20)
+     1,SSCV(5000,20,20),PSES(5000,20),PSCV(5000,20,20),TRAN(5000,20,20)
 c      COMMON/KFASAV/PRE,PRV,FSER,FVAR,SSER,SVAR,FSES,FSCV,SSES,SSCV
 c     1,PSES,PSCV,TRAN
       COMMON/KFASAV/FSES,FSCV,SSES,SSCV
@@ -72,9 +73,9 @@ c      COMMON/MODEL/PFI,ARP,VRI,CCV,SCALE,VR,CONST,PHI,LYAP,PRDG,SCC,fct
       common/model/for, fty
       integer ARI, tra
       common/model/ari,tra      
-      DOUBLE PRECISION FSER1(500),FVAR1(500),
-     *SSER1(500),SVAR1(500)
-      DOUBLE PRECISION SRES1(500)
+      DOUBLE PRECISION FSER1(5000),FVAR1(5000),
+     *SSER1(5000),SVAR1(5000)
+      DOUBLE PRECISION SRES1(5000)
 
       DO 100 I=1,LEN
          FSER1(I)=FSER(I)
