@@ -1,5 +1,6 @@
       SUBROUTINE SETUPDATE (PHI1)
-      INTEGER I,ARP
+      IMPLICIT NONE
+      INTEGER I
 c      INCLUDE 'setcon.txt'
 C*****setcon.txt
       LOGICAL CONV,FAIL
@@ -10,9 +11,14 @@ c     *GMOLD,GMNEW,SIGSQ,OLDB
       COMMON/SETCON/CSO,CSZ,LAM,SSOLD,
      *GMOLD,GMNEW,SIGSQ,OLDB,CONV,FAIL,NP,ITCT,PPIND
 
-      DOUBLE PRECISION PHI(20)
-      COMMON/MODEL/PHI,ARP
       DOUBLE PRECISION PHI1(20)
+      INTEGER PFI,ARP,VRI,CCV,LYAP,SCC,fct
+      DOUBLE PRECISION SCALE,VR,CONST,PHI(20),PRDG
+      COMMON/MODEL/SCALE,VR,CONST,PHI,PRDG,PFI,ARP,VRI,CCV,LYAP,SCC,fct
+      integer for, fty
+      common/model/for, fty
+      integer ARI, tra
+      common/model/ari,tra
 
       DO 100 I=1, ARP+1
          PHI1(I)=PHI(I)
